.. _traitsui-api-reference:

TraitsUI |version| API Reference
================================

This document contains the auto-generated API reference documentation for
TraitsUI.  For user documentation, please read the
:doc:`TraitsUI User Manual <../traitsui_user_manual/index>`

.. toctree::
    :maxdepth: 1

    traitsui
    traitsui.editors
    traitsui.extras
    traitsui.image
    traitsui.null
    traitsui.tests
    traitsui.ui_editors
